@@ -4,11 +4,12 @@
 
 
 from dataclasses import dataclass, field
-from typing import Optional
+from typing import Optional, List
 
 from .inline_keyboard_markup import InlineKeyboardMarkup
 from .inline_query_result import InlineQueryResult
 from .input_message_content import InputMessageContent
+from .message_entity import MessageEntity
 from .parse_mode_type import ParseModeType
 
 
@@ -26,6 +27,7 @@ class InlineQueryResultAudio(InlineQueryResult):
     title: str
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
+    caption_entities: Optional[List[MessageEntity]] = None
     performer: Optional[str] = None
     audio_duration: Optional[int] = None
     reply_markup: Optional[InlineKeyboardMarkup] = None
