@@ -4,11 +4,12 @@
 
 
 from dataclasses import dataclass, field
-from typing import Optional
+from typing import Optional, List
 
 from .inline_keyboard_markup import InlineKeyboardMarkup
 from .inline_query_result import InlineQueryResult
 from .input_message_content import InputMessageContent
+from .message_entity import MessageEntity
 from .parse_mode_type import ParseModeType
 
 
@@ -28,6 +29,7 @@ class InlineQueryResultVideo(InlineQueryResult):
     title: str
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
+    caption_entities: Optional[List[MessageEntity]] = None
     video_width: Optional[int] = None
     video_height: Optional[int] = None
     video_duration: Optional[int] = None
