@@ -4,10 +4,11 @@
 
 
 from dataclasses import dataclass, field
-from typing import Optional, Union
+from typing import Optional, Union, List
 
 from .input_file import InputFile
 from .input_media import InputMedia
+from .message_entity import MessageEntity
 from .parse_mode_type import ParseModeType
 
 
@@ -24,3 +25,5 @@ class InputMediaDocument(InputMedia):
     thumb: Optional[Union[InputFile, str]] = None
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
+    caption_entities: Optional[List[MessageEntity]] = None
+    disable_content_type_detection: Optional[bool] = None
