@@ -39,3 +39,9 @@ class MessageType(EnumAutoName):
     successful_payment = auto()
     connected_website = auto()
     passport_data = auto()
+    proximity_alert_triggered = auto()
+    voice_chat_started = auto()
+    voice_chat_ended = auto()
+    voice_chat_participants_invited = auto()
+    message_auto_delete_timer_changed = auto()
+    unknown = auto()
