@@ -4,8 +4,9 @@
 
 
 from dataclasses import dataclass
-from typing import Union, Optional
+from typing import Union, Optional, List
 
+from .message_entity import MessageEntity
 from .parse_mode_type import ParseModeType
 from .request import Request
 from .utils import ALL_KEYBOARDS, MessageResultMixin
@@ -21,9 +22,9 @@ class SendMessage(MessageResultMixin, Request):
     chat_id: Union[int, str]
     text: str
     parse_mode: Optional[ParseModeType] = None
+    entities: Optional[List[MessageEntity]] = None
     disable_web_page_preview: Optional[bool] = None
     disable_notification: Optional[bool] = None
     reply_to_message_id: Optional[int] = None
+    allow_sending_without_reply: Optional[bool] = None
     reply_markup: Optional[ALL_KEYBOARDS] = None
-
-
