@@ -4,7 +4,7 @@
 
 
 from dataclasses import dataclass
-from typing import Union
+from typing import Union, Optional
 
 from .request import Request
 from .utils import BoolResultMixin
@@ -19,3 +19,4 @@ class UnbanChatMember(BoolResultMixin, Request):
 
     chat_id: Union[int, str]
     user_id: int
+    only_if_banned: Optional[bool]
